# Gemini Breakout

**Breakout** game with Google Gemini AI integrated into it.

# Source Code

The source code of the game **Gemini Breakout** is available in [Source Code](https://github.com/SoftwareApkDev/gemini_breakout/blob/master/gemini_breakout/gemini_breakout.py).

# Installation

```
pip install gemini_breakout
```

# How to Run the Game?

Pre-requisites:

1. [Python](https://www.python.org/downloads/) installed in your device.
2. .env file in the same directory as <GEMINI_BREAKOUT_DIRECTORY> and has the value of GEMINI_API_KEY.

```
cd <GEMINI_BREAKOUT_DIRECTORY>
python gemini_breakout.py
```

**Note:** Replace <GEMINI_BREAKOUT_DIRECTORY> with the path to the directory of the game **Gemini Breakout**.

Then, the game will start like as follows.

![Game Start](images/Game_Start.png)

Once the user presses any key, the game will start.

![Gameplay](images/Gameplay.png)
